--This terminates the list of options. It is useful if the next item on the
command line starts with a hyphen but is not an option. This allows for the
processing of patterns and file names that start with hyphens.
-A number, --after-context=numberOutput up to number lines of context after each matching line. Fewer
lines are output if the next match or the end of the file is reached, or if the
processing buffer size has been set too small. If file names and/or line
numbers are being output, a hyphen separator is used instead of a colon for the
context lines (the -Z option can be used to change the file name
terminator to a zero byte). A line containing -- is output between each group
of lines, unless they are in fact contiguous in the input file. The value of
number is expected to be relatively small. When -c is used,
-A is ignored.
-a, --textTreat binary files as text. This is equivalent to
--binary-files=text.
--allow-lookaround-bskPCRE2 now forbids the use of \K in lookarounds by default, in line with Perl.
This option causes pcre2grep to set the PCRE2_EXTRA_ALLOW_LOOKAROUND_BSK
option, which enables this somewhat dangerous usage.
-B number, --before-context=numberOutput up to number lines of context before each matching line. Fewer
lines are output if the previous match or the start of the file is within
number lines, or if the processing buffer size has been set too small. If
file names and/or line numbers are being output, a hyphen separator is used
instead of a colon for the context lines (the -Z option can be used to
change the file name terminator to a zero byte). A line containing -- is
output between each group of lines, unless they are in fact contiguous in the
input file. The value of number is expected to be relatively small. When
-c is used, -B is ignored.
--binary-files=wordSpecify how binary files are to be processed. If the word is binary (the
default), pattern matching is performed on binary files, but the only output is
Binary file name matches when a match succeeds. If the word is text,
which is equivalent to the -a or --text option, binary files are
processed in the same way as any other file. In this case, when a match
succeeds, the output may be binary garbage, which can have nasty effects if
sent to a terminal. If the word is without-match, which is equivalent to the
-I option, binary files are not processed at all; they are assumed not to
be of interest and are skipped without causing any output or affecting the
return code.
--buffer-size=numberSet the parameter that controls how much memory is obtained at the start of
processing for buffering files that are being scanned. See also
--max-buffer-size below.
-C number, --context=numberOutput number lines of context both before and after each matching line.
This is equivalent to setting both -A and -B to the same value.
-c, --countDo not output lines from the files that are being scanned; instead output the
number of lines that would have been shown, either because they matched, or, if
-v is set, because they failed to match. By default, this count is
exactly the same as the number of lines that would have been output, but if the
-M (multiline) option is used (without -v), there may be more
suppressed lines than the count (that is, the number of matches).
If no lines are selected, the number zero is output. If several files are
being scanned, a count is output for each of them and the -t option can
be used to cause a total to be output at the end. However, if the
--files-with-matches option is also used, only those files whose counts
are greater than zero are listed. When -c is used, the -A,
-B, and -C options are ignored.
--colour, --colorIf this option is given without any data, it is equivalent to --colour=auto.
If data is required, it must be given in the same shell item, separated by an
equals sign.
--colour=value, --color=valueThis option specifies under what circumstances the parts of a line that matched
a pattern should be coloured in the output. It is ignored if
--file-offsets, --line-offsets, or --output is set. By
default, output is not coloured. The value for the --colour option (which
is optional, see above) may be never, always, or auto. In the latter
case, colouring happens only if the standard output is connected to a terminal.
More resources are used when colouring is enabled, because pcre2grep has
to search for all possible matches in a line, not just one, in order to colour
them all.
The colour that is used can be specified by setting one of the environment
variables PCRE2GREP_COLOUR, PCRE2GREP_COLOR, PCREGREP_COLOUR, or
PCREGREP_COLOR, which are checked in that order. If none of these are set,
pcre2grep looks for GREP_COLORS or GREP_COLOR (in that order). The value
of the variable should be a string of two numbers, separated by a semicolon,
except in the case of GREP_COLORS, which must start with ms= or mt=
followed by two semicolon-separated colours, terminated by the end of the
string or by a colon. If GREP_COLORS does not start with ms= or mt= it is
ignored, and GREP_COLOR is checked.
If the string obtained from one of the above variables contains any characters
other than semicolon or digits, the setting is ignored and the default colour
is used. The string is copied directly into the control string for setting
colour on a terminal, so it is your responsibility to ensure that the values
make sense. If no relevant environment variable is set, the default is 1;31,
which gives red.
-D action, --devices=actionIf an input path is not a regular file or a directory, action specifies how
it is to be processed. Valid values are read (the default) or skip
(silently skip the path).
-d action, --directories=actionIf an input path is a directory, action specifies how it is to be processed.
Valid values are read (the default in non-Windows environments, for
compatibility with GNU grep), recurse (equivalent to the -r option), or
skip (silently skip the path, the default in Windows environments). In the
read case, directories are read as if they were ordinary files. In some
operating systems the effect of reading a directory like this is an immediate
end-of-file; in others it may provoke an error.
--depth-limit=numberSee --match-limit below.
-E, --case-restrictWhen case distinctions are being ignored in Unicode mode, two ASCII letters (K
and S) will by default match Unicode characters U+212A (Kelvin sign) and U+017F
(long S) respectively, as well as their lower case ASCII counterparts. When
this option is set, case equivalences are restricted such that no ASCII
character matches a non-ASCII character, and vice versa.
-e pattern, --regex=pattern, --regexp=patternSpecify a pattern to be matched. This option can be used multiple times in
order to specify several patterns. It can also be used as a way of specifying a
single pattern that starts with a hyphen. When -e is used, no argument
pattern is taken from the command line; all arguments are treated as file
names. There is no limit to the number of patterns. They are applied to each
line in the order in which they are defined.
If -f is used with -e, the command line patterns are matched first,
followed by the patterns from the file(s), independent of the order in which
these options are specified.
--exclude=patternFiles (but not directories) whose names match the pattern are skipped without
being processed. This applies to all files, whether listed on the command line,
obtained from --file-list, or by scanning a directory. The pattern is a
PCRE2 regular expression, and is matched against the final component of the
file name, not the entire path. The -F, -w, and -x options do
not apply to this pattern. The option may be given any number of times in order
to specify multiple patterns. If a file name matches both an --include
and an --exclude pattern, it is excluded. There is no short form for this
option.
--exclude-from=filenameTreat each non-empty line of the file as the data for an --exclude
option. What constitutes a newline when reading the file is the operating
system’s default. The --newline option has no effect on this option. This
option may be given more than once in order to specify a number of files to
read.
--exclude-dir=patternDirectories whose names match the pattern are skipped without being processed,
whatever the setting of the --recursive option. This applies to all
directories, whether listed on the command line, obtained from
--file-list, or by scanning a parent directory. The pattern is a PCRE2
regular expression, and is matched against the final component of the directory
name, not the entire path. The -F, -w, and -x options do not
apply to this pattern. The option may be given any number of times in order to
specify more than one pattern. If a directory matches both --include-dir
and --exclude-dir, it is excluded. There is no short form for this
option.
-F, --fixed-stringsInterpret each data-matching pattern as a list of fixed strings, separated by
newlines, instead of as a regular expression. What constitutes a newline for
this purpose is controlled by the --newline option. The -w (match
as a word) and -x (match whole line) options can be used with -F.
They apply to each of the fixed strings. A line is selected if any of the fixed
strings are found in it (subject to -w or -x, if present). This
option applies only to the patterns that are matched against the contents of
files; it does not apply to patterns specified by any of the --include or
--exclude options.
-f filename, --file=filenameRead patterns from the file, one per line. As is the case with patterns on the
command line, no delimiters should be used. What constitutes a newline when
reading the file is the operating system’s default interpretation of \n. The
--newline option has no effect on this option. Trailing white space is
removed from each line, and blank lines are ignored unless the
--posix-pattern-file option is also provided. An empty file contains no
patterns and therefore matches nothing. Patterns read from a file in this way
may contain binary zeros, which are treated as ordinary character literals.
If this option is given more than once, all the specified files are read. A
data line is output if any of the patterns match it. A file name can be given
as - to refer to the standard input. When -f is used, patterns
specified on the command line using -e may also be present; they are
matched before the file’s patterns. However, no pattern is taken from the
command line; all arguments are treated as the names of paths to be searched.
--file-list=filenameRead a list of files and/or directories that are to be scanned from the given
file, one per line. What constitutes a newline when reading the file is the
operating system’s default. Trailing white space is removed from each line, and
blank lines are ignored. These paths are processed before any that are listed
on the command line. The file name can be given as - to refer to the standard
input. If --file and --file-list are both specified as -,
patterns are read first. This is useful only when the standard input is a
terminal, from which further lines (the list of files) can be read after an
end-of-file indication. If this option is given more than once, all the
specified files are read.
--file-offsetsInstead of showing lines or parts of lines that match, show each match as an
offset from the start of the file and a length, separated by a comma. In this
mode, --colour has no effect, and no context is shown. That is, the
-A, -B, and -C options are ignored. If there is more than one
match in a line, each of them is shown separately. This option is mutually
exclusive with --output, --line-offsets, and --only-matching.
--group-separator=textOutput this text string instead of two hyphens between groups of lines when
-A, -B, or -C is in use. See also --no-group-separator.
-H, --with-filenameForce the inclusion of the file name at the start of output lines when
searching a single file. The file name is not normally shown in this case.
By default, for matching lines, the file name is followed by a colon; for
context lines, a hyphen separator is used. The -Z option can be used to
change the terminator to a zero byte. If a line number is also being output,
it follows the file name. When the -M option causes a pattern to match
more than one line, only the first is preceded by the file name. This option
overrides any previous -h, -l, or -L options.
-h, --no-filenameSuppress the output file names when searching multiple files. File names are
normally shown when multiple files are searched. By default, for matching
lines, the file name is followed by a colon; for context lines, a hyphen
separator is used. The -Z option can be used to change the terminator to
a zero byte. If a line number is also being output, it follows the file name.
This option overrides any previous -H, -L, or -l options.
--heap-limit=numberSee --match-limit below.
--helpOutput a help message, giving brief details of the command options and file
type support, and then exit. Anything else on the command line is
ignored.
-IIgnore binary files. This is equivalent to
--binary-files=without-match.
-i, --ignore-caseIgnore upper/lower case distinctions when pattern matching. This applies when
matching path names for inclusion or exclusion as well as when matching lines
in files.
--include=patternIf any --include patterns are specified, the only files that are
processed are those whose names match one of the patterns and do not match an
--exclude pattern. This option does not affect directories, but it
applies to all files, whether listed on the command line, obtained from
--file-list, or by scanning a directory. The pattern is a PCRE2 regular
expression, and is matched against the final component of the file name, not
the entire path. The -F, -w, and -x options do not apply to
this pattern. The option may be given any number of times. If a file name
matches both an --include and an --exclude pattern, it is excluded.
There is no short form for this option.
--include-from=filenameTreat each non-empty line of the file as the data for an --include
option. What constitutes a newline for this purpose is the operating system’s
default. The --newline option has no effect on this option. This option
may be given any number of times; all the files are read.
--include-dir=patternIf any --include-dir patterns are specified, the only directories that
are processed are those whose names match one of the patterns and do not match
an --exclude-dir pattern. This applies to all directories, whether listed
on the command line, obtained from --file-list, or by scanning a parent
directory. The pattern is a PCRE2 regular expression, and is matched against
the final component of the directory name, not the entire path. The -F,
-w, and -x options do not apply to this pattern. The option may be
given any number of times. If a directory matches both --include-dir and
--exclude-dir, it is excluded. There is no short form for this option.
-L, --files-without-matchInstead of outputting lines from the files, just output the names of the files
that do not contain any lines that would have been output. Each file name is
output once, on a separate line by default, but if the -Z option is set,
they are separated by zero bytes instead of newlines. This option overrides any
previous -H, -h, or -l options.
-l, --files-with-matchesInstead of outputting lines from the files, just output the names of the files
containing lines that would have been output. Each file name is output once, on
a separate line, but if the -Z option is set, they are separated by zero
bytes instead of newlines. Searching normally stops as soon as a matching line
is found in a file. However, if the -c (count) option is also used,
matching continues in order to obtain the correct count, and those files that
have at least one match are listed along with their counts. Using this option
with -c is a way of suppressing the listing of files with no matches that
occurs with -c on its own. This option overrides any previous -H,
-h, or -L options.
--label=nameThis option supplies a name to be used for the standard input when file names
are being output. If not supplied, (standard input) is used. There is no
short form for this option.
--lfUse LF as the line ending for standard output. This has no effect except on
Windows, where CRLF is the default. There is no short form for this option.
--line-bufferedWhen this option is given, non-compressed input is read and processed line by
line, and the output is flushed after each write. By default, input is read in
large chunks, unless pcre2grep can determine that it is reading from a
terminal, which is currently possible only in Unix-like environments or
Windows. Output to terminal is normally automatically flushed by the operating
system. This option can be useful when the input or output is attached to a
pipe and you do not want pcre2grep to buffer up large amounts of data.
However, its use will affect performance, and the -M (multiline) option
ceases to work. When input is from a compressed .gz or .bz2 file,
--line-buffered is ignored.
--line-offsetsInstead of showing lines or parts of lines that match, show each match as a
line number, the offset from the start of the line, and a length. The line
number is terminated by a colon (as usual; see the -n option), and the
offset and length are separated by a comma. In this mode, --colour has no
effect, and no context is shown. That is, the -A, -B, and -C
options are ignored. If there is more than one match in a line, each of them is
shown separately. This option is mutually exclusive with --output,
--file-offsets, and --only-matching.
--locale=locale-nameThis option specifies a locale to be used for pattern matching. It overrides
the value in the LC_ALL or LC_CTYPE environment variables. If no
locale is specified, the PCRE2 library’s default (usually the "C" locale) is
used. There is no short form for this option.
-M, --multilineAllow patterns to match more than one line. When this option is set, the PCRE2
library is called in "multiline" mode, and a match is allowed to continue past
the end of the initial line and onto one or more subsequent lines.
Patterns used with -M may usefully contain literal newline characters and
internal occurrences of ^ and $ characters, because in multiline mode these can
match at internal newlines. Because pcre2grep is scanning multiple lines,
the \Z and \z assertions match only at the end of the last line in the file.
The \A assertion matches at the start of the first line of a match. This can
be any line in the file; it is not anchored to the first line.
The output for a successful match may consist of more than one line. The first
line is the line in which the match started, and the last line is the line in
which the match ended. If the matched string ends with a newline sequence, the
output ends at the end of that line. If -v is set, none of the lines in a
multi-line match are output. Once a match has been handled, scanning restarts
at the beginning of the line after the one in which the match ended.
The newline sequence that separates multiple lines must be matched as part of
the pattern. For example, to find the phrase regular expression in a file
where regular might be at the end of a line and expression at the start of
the next line, you could use this command:
pcre2grep -M 'regular\s+expression' <file>
The \s escape sequence matches any white space character, including newlines,
and is followed by + so as to match trailing white space on the first line as
well as possibly handling a two-character newline sequence.
There is a limit to the number of lines that can be matched, imposed by the way
that pcre2grep buffers the input file as it scans it. With a sufficiently
large processing buffer, this should not be a problem.
The -M option does not work when input is read line by line (see
--line-buffered.)
-m number, --max-count=numberStop processing after finding number matching lines, or non-matching
lines if -v is also set. Any trailing context lines are output after the
final match. In multiline mode, each multiline match counts as just one line
for this purpose. If this limit is reached when reading the standard input from
a regular file, the file is left positioned just after the last matching line.
If -c is also set, the count that is output is never greater than
number. This option has no effect if used with -L, -l, or
-q, or when just checking for a match in a binary file.
--match-limit=numberProcessing some regular expression patterns may take a very long time to search
for all possible matching strings. Others may require a very large amount of
memory. There are three options that set resource limits for matching.
The --match-limit option provides a means of limiting computing resource
usage when processing patterns that are not going to match, but which have a
very large number of possibilities in their search trees. The classic example
is a pattern that uses nested unlimited repeats. Internally, PCRE2 has a
counter that is incremented each time around its main processing loop. If the
value set by --match-limit is reached, an error occurs.
The --heap-limit option specifies, as a number of kibibytes (units of
1024 bytes), the maximum amount of heap memory that may be used for matching.
The --depth-limit option limits the depth of nested backtracking points,
which indirectly limits the amount of memory that is used. The amount of memory
needed for each backtracking point depends on the number of capturing
parentheses in the pattern, so the amount of memory that is used before this
limit acts varies from pattern to pattern. This limit is of use only if it is
set smaller than --match-limit.
There are no short forms for these options. The default limits can be set
when the PCRE2 library is compiled; if they are not specified, the defaults
are very large and so effectively unlimited.
--max-buffer-size=numberThis limits the expansion of the processing buffer, whose initial size can be
set by --buffer-size. The maximum buffer size is silently forced to be no
smaller than the starting buffer size.
-N newline-type, --newline=newline-typeSix different conventions for indicating the ends of lines in scanned files are
supported. For example:
pcre2grep -N CRLF 'some pattern' <file>
The newline type may be specified in upper, lower, or mixed case. If the
newline type is NUL, lines are separated by binary zero characters. The other
types are the single-character sequences CR (carriage return) and LF
(linefeed), the two-character sequence CRLF, an "anycrlf" type, which
recognizes any of the preceding three types, and an "any" type, for which any
Unicode line ending sequence is assumed to end a line. The Unicode sequences
are the three just mentioned, plus VT (vertical tab, U+000B), FF (form feed,
U+000C), NEL (next line, U+0085), LS (line separator, U+2028), and PS
(paragraph separator, U+2029).
When the PCRE2 library is built, a default line-ending sequence is specified.
This is normally the standard sequence for the operating system. Unless
otherwise specified by this option, pcre2grep uses the library’s default.
This option makes it possible to use pcre2grep to scan files that have
come from other environments without having to modify their line endings. If
the data that is being scanned does not agree with the convention set by this
option, pcre2grep may behave in strange ways. Note that this option does
not apply to files specified by the -f, --exclude-from, or
--include-from options, which are expected to use the operating system’s
standard newline sequence.
-n, --line-numberPrecede each output line by its line number in the file, followed by a colon
for matching lines or a hyphen for context lines. If the file name is also
being output, it precedes the line number. When the -M option causes a
pattern to match more than one line, only the first is preceded by its line
number. This option is forced if --line-offsets is used.
--no-group-separatorDo not output a separator between groups of lines when -A, -B, or
-C is in use. The default is to output a line containing two hyphens. See
also --group-separator.
--no-jitIf the PCRE2 library is built with support for just-in-time compiling (which
speeds up matching), pcre2grep automatically makes use of this, unless it
was explicitly disabled at build time. This option can be used to disable the
use of JIT at run time. It is provided for testing and working around problems.
It should never be needed in normal use.
-O text, --output=textWhen there is a match, instead of outputting the line that matched, output just
the text specified in this option, followed by an operating-system standard
newline. In this mode, --colour has no effect, and no context is shown.
That is, the -A, -B, and -C options are ignored. The
--newline option has no effect on this option, which is mutually
exclusive with --only-matching, --file-offsets, and
--line-offsets. However, like --only-matching, if there is more
than one match in a line, each of them causes a line of output.
Escape sequences starting with a dollar character may be used to insert the
contents of the matched part of the line and/or captured substrings into the
text.
$digits or ${digits} is replaced by the captured substring of the given
decimal number; $& (or the legacy $0) substitutes the whole match. If the
number is greater than the number of capturing substrings, or if the capture
is unset, the replacement is empty.
$a is replaced by bell; $b by backspace; $e by escape; $f by form feed; $n by
newline; $r by carriage return; $t by tab; $v by vertical tab.
$odigits or $o{digits} is replaced by the character whose code point is
the given octal number. In the first form, up to three octal digits are processed.
When more digits are needed in Unicode mode to specify a wide character, the
second form must be used.
$xdigits or $x{digits} is replaced by the character represented by
the given hexadecimal number. In the first form, up to two hexadecimal digits are
processed. When more digits are needed in Unicode mode to specify a wide
character, the second form must be used.
Any other character is substituted by itself. In particular, $$ is replaced by
a single dollar.
-o, --only-matchingShow only the part of the line that matched a pattern instead of the whole
line. In this mode, no context is shown. That is, the -A, -B, and
-C options are ignored. If there is more than one match in a line, each
of them is shown separately, on a separate line of output. If -o is
combined with -v (invert the sense of the match to find non-matching
lines), no output is generated, but the return code is set appropriately. If
the matched portion of the line is empty, nothing is output unless the file
name or line number are being printed, in which case they are shown on an
otherwise empty line. This option is mutually exclusive with --output,
--file-offsets and --line-offsets.
-onumber, --only-matching=numberShow only the part of the line that matched the capturing parentheses of the
given number. Up to 50 capturing parentheses are supported by default. This
limit can be changed via the --om-capture option. A pattern may contain
any number of capturing parentheses, but only those whose number is within the
limit can be accessed by -o. An error occurs if the number specified by
-o is greater than the limit.
-o0 is the same as -o without a number. Because these options can be
given without an argument (see above), if an argument is present, it must be
given in the same shell item, for example, -o3 or --only-matching=2. The
comments given for the non-argument case above also apply to this option. If
the specified capturing parentheses do not exist in the pattern, or were not
set in the match, nothing is output unless the file name or line number are
being output.
If this option is given multiple times, multiple substrings are output for each
match, in the order the options are given, and all on one line. For example,
-o3 -o1 -o3 causes the substrings matched by capturing parentheses 3 and 1 and
then 3 again to be output. By default, there is no separator (but see the next
but one option).
--om-capture=numberSet the number of capturing parentheses that can be accessed by -o. The
default is 50.
--om-separator=textSpecify a separating string for multiple occurrences of -o. The default
is an empty string. Separating strings are never coloured.
-P, --no-ucpStarting from release 10.43, when UTF/Unicode mode is specified with -u
or -U, the PCRE2_UCP option is used by default. This means that the
POSIX classes in patterns match more than just ASCII characters. For example,
[:digit:] matches any Unicode decimal digit. The --no-ucp option
suppresses PCRE2_UCP, thus restricting the POSIX classes to ASCII characters,
as was the case in earlier releases. Note that there are now more fine-grained
option settings within patterns that affect individual classes. For example,
when in UCP mode, the sequence (?aP) restricts [:word:] to ASCII letters, while
allowing \w to match Unicode letters and digits.
--posix-pattern-fileWhen patterns are provided with the -f option, do not trim trailing
spaces or ignore empty lines in a similar way than other grep tools. To keep
the behaviour consistent with older versions, if the pattern read was
terminated with CRLF (as character literals) then both characters won’t be
included as part of it, so if you really need to have pattern ending in \r,
use a escape sequence or provide it by a different method.
-q, --quietWork quietly, that is, display nothing except error messages. The exit
status indicates whether or not any matches were found.
-r, --recursiveIf any given path is a directory, recursively scan the files it contains,
taking note of any --include and --exclude settings. By default, a
directory is read as a normal file; in some operating systems this gives an
immediate end-of-file. This option is a shorthand for setting the -d
option to "recurse".
--recursion-limit=numberThis is an obsolete synonym for --depth-limit. See --match-limit
above for details.
-s, --no-messagesSuppress error messages about non-existent or unreadable files. Such files are
quietly skipped. However, the return code is still 2, even if matches were
found in other files.
-t, --total-countThis option is useful when scanning more than one file. If used on its own,
-t suppresses all output except for a grand total number of matching
lines (or non-matching lines if -v is used) in all the files. If -t
is used with -c, a grand total is output except when the previous output
is just one line. In other words, it is not output when just one file’s count
is listed. If file names are being output, the grand total is preceded by
TOTAL:. Otherwise, it appears as just another number. The -t option is
ignored when used with -L (list files without matches), because the grand
total would always be zero.
-u, --utfOperate in UTF/Unicode mode. This option is available only if PCRE2 has been
compiled with UTF-8 support. All patterns (including those for any
--exclude and --include options) and all lines that are scanned
must be valid strings of UTF-8 characters. If an invalid UTF-8 string is
encountered, an error occurs.
-U, --utf-allow-invalidAs --utf, but in addition subject lines may contain invalid UTF-8 code
unit sequences. These can never form part of any pattern match. Patterns
themselves, however, must still be valid UTF-8 strings. This facility allows
valid UTF-8 strings to be sought within arbitrary byte sequences in executable
or other binary files. For more details about matching in non-valid UTF-8
strings, see the
pcre2unicode
documentation.
-V, --versionWrite the version numbers of pcre2grep and the PCRE2 library to the
standard output and then exit. Anything else on the command line is
ignored.
-v, --invert-matchInvert the sense of the match, so that lines which do not match any of
the patterns are the ones that are found. When this option is set, options such
as --only-matching and --output, which specify parts of a match
that are to be output, are ignored.
-w, --word-regex, --word-regexpForce the patterns only to match "words". That is, there must be a word
boundary at the start and end of each matched string. This is equivalent to
having \b(?: at the start of each pattern, and )\b at the end. This
option applies only to the patterns that are matched against the contents of
files; it does not apply to patterns specified by any of the --include or
--exclude options.
-x, --line-regex, --line-regexpForce the patterns to start matching only at the beginnings of lines, and in
addition, require them to match entire lines. In multiline mode the match may
be more than one line. This is equivalent to having ^(?: at the start of each
pattern and )$ at the end. This option applies only to the patterns that are
matched against the contents of files; it does not apply to patterns specified
by any of the --include or --exclude options.
-Z, --nullTerminate files names in the regular output with a zero byte (the NUL
character) instead of what would normally appear. This is useful when file
names contain unusual characters such as colons, hyphens, or even newlines. The
option does not apply to file names in error messages.